@@ -1,5 +1,5 @@
 from ._cli import cli
-from ._misc import num_models
+from ._misc import fetch_metadata, num_models
 from ._reader import HMMERModel, HMMERParser, ParsingError, open_hmmer
 from ._testit import test
 from ._version import __version__
@@ -10,6 +10,7 @@ __all__ = [
     "ParsingError",
     "__version__",
     "cli",
+    "fetch_metadata",
     "num_models",
     "open_hmmer",
     "test",
